@@ -16,7 +16,7 @@ use Time::Strptime::TimeZone;
 
 use constant DEBUG => exists $ENV{PERL_TIME_STRPTIME_DEBUG} && $ENV{PERL_TIME_STRPTIME_DEBUG};
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 our %DEFAULT_HANDLER = (
     '%' => [char          => '%' ],
@@ -248,6 +248,11 @@ sub _gen_calc_epoch_src {
     elsif ($types_table->{year} && $types_table->{month} && $types_table->{day}) {
         $src .= <<EOD;
     \$epoch = timegm_nocheck($second, $minute, $hour, \$day, \$month - 1, \$year);
+EOD
+    }
+    elsif ($types_table->{year} && $types_table->{month}) {
+        $src .= <<EOD;
+    \$epoch = timegm_nocheck($second, $minute, $hour, 1, \$month - 1, \$year);
 EOD
     }
     elsif ($types_table->{year} && $types_table->{day365}) {
